@@ -1,5 +1,6 @@
 /*************************************************************************************
  *  Copyright (C) 2007-2009 by Aleix Pol <aleixpol@kde.org>                          *
+ *  Copyright (C) 2014 by Percy Camilo T. Aucahuasi <percy.camilo.ta@gmail.com>      *
  *                                                                                   *
  *  This program is free software; you can redistribute it and/or                    *
  *  modify it under the terms of the GNU General Public License                      *
@@ -18,7 +19,7 @@
 
 #include "analitzautils.h"
 
-#include "expressionwriter.h"
+#include "abstractexpressionvisitor.h"
 #include "vector.h"
 #include "value.h"
 #include "list.h"
@@ -280,14 +281,17 @@ bool hasVars(const Analitza::Object* o, const QStringList& bvars)
 	return r;
 }
 
-struct ObjectWalker : public ExpressionWriter
+struct ObjectWalker : public AbstractExpressionVisitor
 {
 	ObjectWalker(const QByteArray& pref) : ind(0), m_prefix(pref) {}
 	
-	virtual QString accept(const Operator* root)
+	virtual QVariant visit(const None* var)
+	{ qDebug() << prefix().constData() << "| none: " << var->toString(); return QString(); }
+	
+	virtual QVariant visit(const Operator* root)
 	{ qDebug() << prefix().constData() << "| operator: " << root->toString(); return QString(); }
 	
-	virtual QString accept(const Ci* var)
+	virtual QVariant visit(const Ci* var)
  	{
 		QString value;
 		if(var->depth()>=0)
@@ -299,14 +303,14 @@ struct ObjectWalker : public ExpressionWriter
 		return QString();
 	}
 	
-	virtual QString accept(const Cn* num)
+	virtual QVariant visit(const Cn* num)
 	{ qDebug() << prefix().constData() << "| num: " << num->value() << " format: " << num->format(); return QString(); }
 	
-	virtual QString accept(const CustomObject* c)
+	virtual QVariant visit(const CustomObject* c)
 	{ qDebug() << prefix().constData() << "| custom " << c; return QString(); }
 	
 	
-	virtual QString accept(const Container* c)
+	virtual QVariant visit(const Container* c)
 	{
 		qDebug() << prefix().constData() << "| cont: " << c->tagName();// << "=" << c->toString();
 		ind++;
@@ -316,7 +320,7 @@ struct ObjectWalker : public ExpressionWriter
 		return QString();
 	}
 	
-	virtual QString accept ( const Apply* c )
+	virtual QVariant visit(const Apply* c)
 	{
 		qDebug() << prefix().constData() << "| apply op:" << c->firstOperator().toString();
 		ind++;
@@ -330,7 +334,7 @@ struct ObjectWalker : public ExpressionWriter
 		return QString();
 	}
 	
-	virtual QString accept(const Vector* v)
+	virtual QVariant visit(const Vector* v)
 	{
 		qDebug() << prefix().constData() << "| vector: " << v->size();
 		ind++;
@@ -340,7 +344,7 @@ struct ObjectWalker : public ExpressionWriter
 		return QString();
 	}
 	
-	virtual QString accept(const List* v)
+	virtual QVariant visit(const List* v)
 	{
 		qDebug() << prefix().constData() << "| list: " << v->size();
 		ind++;
@@ -350,7 +354,7 @@ struct ObjectWalker : public ExpressionWriter
 		return QString();
 	}
 	
-	virtual QString accept(const Matrix* m) {
+	virtual QVariant visit(const Matrix* m) {
 		qDebug() << prefix().constData() << "| matrix: ";
 		ind++;
 		for(Matrix::const_iterator it=m->constBegin(); it!=m->constEnd(); ++it)
@@ -359,7 +363,7 @@ struct ObjectWalker : public ExpressionWriter
 		return QString();
 	}
 	
-	virtual QString accept(const MatrixRow* m) {
+	virtual QVariant visit(const MatrixRow* m) {
 		qDebug() << prefix().constData() << "| matrix: ";
 		ind++;
 		for(MatrixRow::const_iterator it=m->constBegin(); it!=m->constEnd(); ++it)
@@ -376,9 +380,9 @@ struct ObjectWalker : public ExpressionWriter
 		return ret;
 	}
 	
-	void visitNow(const Object* o) { if(o) o->visit(this); else qDebug() << prefix().constData() << "Null" ;}
+	void visitNow(const Object* o) { if(o) o->accept(this); else qDebug() << prefix().constData() << "Null" ;}
 	
-	QString result() const { return QString(); }
+	QVariant result() const { return QString(); }
 	
 	int ind;
 	QByteArray m_prefix;
@@ -471,6 +475,7 @@ QVariant expressionToVariant(const Analitza::Expression& res)
 			case Analitza::Cn::Char:
 				ret = val.character();
 				break;
+			case Analitza::Cn::Complex: //TODO: figure out complex numbers on QVariant
 			case Analitza::Cn::Real:
 				ret = val.value();
 				break;
@@ -512,12 +517,12 @@ QString listToString(const List* list)
 	return ret;
 }
 
-template<class T, class Tit>
+template<class T, class Tit, class Tcontained = Object>
 T* replaceDepthTemplate(int depth, T* tree, Object* towhat)
 {
 	Tit it=tree->begin(), itEnd=tree->end();
 	for(; it!=itEnd; ++it)
-		*it = replaceDepth(depth, *it, towhat);
+		*it = static_cast<Tcontained*>(replaceDepth(depth, *it, towhat));
 	return tree;
 }
 
@@ -538,7 +543,7 @@ Object* replaceDepth(int depth, Object* tree, Object* towhat)
 		case Object::vector:
 			return replaceDepthTemplate<Vector, Vector::iterator>(depth, static_cast<Vector*>(tree), towhat);
 		case Object::matrix:
-			return replaceDepthTemplate<Matrix, Matrix::iterator>(depth, static_cast<Matrix*>(tree), towhat);
+			return replaceDepthTemplate<Matrix, Matrix::iterator, MatrixRow>(depth, static_cast<Matrix*>(tree), towhat);
 		case Object::matrixrow:
 			return replaceDepthTemplate<MatrixRow, MatrixRow::iterator>(depth, static_cast<MatrixRow*>(tree), towhat);
 		case Object::container:
