@@ -38,6 +38,7 @@ class ANALITZA_EXPORT ExpressionTypeChecker : public AbstractExpressionVisitor
 		
 		ExpressionType check(const Expression& exp);
 		
+		virtual QVariant visit(const None* var);
 		virtual QVariant visit(const Operator* var);
 		virtual QVariant visit(const Ci* var);
 		virtual QVariant visit(const Cn* var);
@@ -56,7 +57,7 @@ class ANALITZA_EXPORT ExpressionTypeChecker : public AbstractExpressionVisitor
 		bool isCorrect() const { return m_err.isEmpty() && !current.isError(); }
 		QStringList errors() const;
 		
-		void initializeVars(const QMap<QString, ExpressionType>& types) { m_vars=types; }
+		void initializeVars(const QMap<QString, ExpressionType>& types);
 		QMap<QString, ExpressionType> variablesTypes() const;
 		
 	private:
