@@ -20,7 +20,6 @@
 // #include "private/surfacefactory.h"
 #include "private/functiongraphfactory.h"
 
-#include <analitza/localize.h>
 #include <analitza/value.h>
 #include <analitza/vector.h>
 
@@ -33,7 +32,7 @@ class ImplicitSurf : public AbstractSurface , public MarchingCubes/*, static cla
 public:
     ImplicitSurf(const Analitza::Expression& e, Analitza::Variables* v);
 
-    TYPE_NAME(I18N_NOOP("Implicit Surface"))
+    TYPE_NAME(QT_TR_NOOP("Implicit Surface"))
     EXPRESSION_TYPE(Analitza::ExpressionType(Analitza::ExpressionType::Lambda)
         .addParameter(Analitza::ExpressionType(Analitza::ExpressionType::Value))
         .addParameter(Analitza::ExpressionType(Analitza::ExpressionType::Value))
@@ -66,7 +65,7 @@ ImplicitSurf::ImplicitSurf(const Analitza::Expression& e, Analitza::Variables* v
 
 }
 
-void ImplicitSurf::update(const QVector3D & oppositecorner1, const QVector3D & oppositecorner2)
+void ImplicitSurf::update(const QVector3D & /*oppositecorner1*/, const QVector3D & /*oppositecorner2*/)
 {
     SpaceLimits spaceLimits;
     
