@@ -21,8 +21,8 @@
 #include "abstractfunctiongraph.h"
 
 #include <QStringList>
+#include <QCoreApplication>
 #include <analitza/analyzer.h>
-#include <KLocalizedString>
 
 using namespace Analitza;
 
@@ -30,7 +30,7 @@ FunctionGraphFactory* FunctionGraphFactory::m_self=0;
 
 QString FunctionGraphFactory::typeName(const QString& id) const
 {
-    return i18n(typeNameFunctions[id]);
+    return QCoreApplication::tr(typeNameFunctions[id]);
 }
 
 Analitza::ExpressionType FunctionGraphFactory::expressionType(const QString& id) const
@@ -131,6 +131,7 @@ bool FunctionGraphFactory::contains(const QString& id) const
 
 AbstractFunctionGraph* FunctionGraphFactory::build(const QString& id, const Analitza::Expression& exp, Analitza::Variables* v) const
 {
+    Q_ASSERT(builderFunctionsWithVars.contains(id));
     AbstractFunctionGraph* ret = builderFunctionsWithVars.value(id)(exp, v);
     ret->setInternalId(id);
     return ret;
